@@ -108,6 +108,8 @@ static inline PixelTrait GetPixelCbTraits(const Image *magick_restrict image)
 static inline Quantum GetPixelChannel(const Image *magick_restrict image,
   const PixelChannel channel,const Quantum *magick_restrict pixel)
 {
+  if (((ssize_t) channel < 0) || ((ssize_t) channel >= MaxPixelChannels))
+    return((Quantum) 0);
   if (image->channel_map[channel].traits == UndefinedPixelTrait)
     return((Quantum) 0);
   return(pixel[image->channel_map[channel].offset]);
@@ -116,6 +118,8 @@ static inline Quantum GetPixelChannel(const Image *magick_restrict image,
 static inline PixelChannel GetPixelChannelChannel(
   const Image *magick_restrict image,const ssize_t offset)
 {
+  if ((offset < 0) || (offset >= MaxPixelChannels))
+    return(UndefinedPixelChannel);
   return(image->channel_map[offset].channel);
 }
 
@@ -128,6 +132,8 @@ static inline ssize_t GetPixelChannelOffset(const Image *magick_restrict image,
 static inline PixelTrait GetPixelChannelTraits(
   const Image *magick_restrict image,const PixelChannel channel)
 {
+  if (((ssize_t) channel < 0) || ((ssize_t) channel >= MaxPixelChannels))
+    return(UndefinedPixelTrait);
   return(image->channel_map[channel].traits);
 }
 
@@ -345,14 +351,14 @@ static inline PixelTrait GetPixelMagentaTraits(
 static inline Quantum GetPixelMeta(const Image *magick_restrict image,
   const Quantum *magick_restrict pixel)
 {
-  if (image->channel_map[MetaPixelChannel].traits == UndefinedPixelTrait)
+  if (image->channel_map[MetaPixelChannels].traits == UndefinedPixelTrait)
     return(OpaqueAlpha);
-  return(pixel[image->channel_map[MetaPixelChannel].offset]);
+  return(pixel[image->channel_map[MetaPixelChannels].offset]);
 }
 
 static inline PixelTrait GetPixelMetaTraits(const Image *magick_restrict image)
 {
-  return(image->channel_map[MetaPixelChannel].traits);
+  return(image->channel_map[MetaPixelChannels].traits);
 }
 
 static inline Quantum GetPixelReadMask(const Image *magick_restrict image,
@@ -457,6 +463,8 @@ static inline void GetPixelInfoPixel(const Image *magick_restrict image,
 static inline PixelTrait GetPixelTraits(const Image *magick_restrict image,
   const PixelChannel channel)
 {
+  if (((ssize_t) channel < 0) || ((ssize_t) channel >= MaxPixelChannels))
+    return(UndefinedPixelTrait);
   return(image->channel_map[channel].traits);
 }
 
@@ -743,6 +751,8 @@ static inline void SetPixelChannel(const Image *magick_restrict image,
   const PixelChannel channel,const Quantum quantum,
   Quantum *magick_restrict pixel)
 {
+  if (((ssize_t) channel < 0) || ((ssize_t) channel >= MaxPixelChannels))
+    return;
   if (image->channel_map[channel].traits != UndefinedPixelTrait)
     pixel[image->channel_map[channel].offset]=quantum;
 }
@@ -751,9 +761,9 @@ static inline void SetPixelChannelAttributes(
   const Image *magick_restrict image,const PixelChannel channel,
   const PixelTrait traits,const ssize_t offset)
 {
-  if ((ssize_t) channel >= MaxPixelChannels)
+  if (((ssize_t) offset < 0) || ((ssize_t) offset >= MaxPixelChannels))
     return;
-  if (offset >= MaxPixelChannels)
+  if (((ssize_t) channel < 0) || ((ssize_t) channel >= MaxPixelChannels))
     return;
   image->channel_map[offset].channel=channel;
   image->channel_map[channel].offset=offset;
@@ -763,6 +773,10 @@ static inline void SetPixelChannelAttributes(
 static inline void SetPixelChannelChannel(const Image *magick_restrict image,
   const PixelChannel channel,const ssize_t offset)
 {
+  if (((ssize_t) offset < 0) || ((ssize_t) offset >= MaxPixelChannels))
+    return;
+  if (((ssize_t) channel < 0) || ((ssize_t) channel >= MaxPixelChannels))
+    return;
   image->channel_map[offset].channel=channel;
   image->channel_map[channel].offset=offset;
 }
@@ -775,6 +789,8 @@ static inline void SetPixelChannels(Image *image,const size_t number_channels)
 static inline void SetPixelChannelTraits(Image *image,
   const PixelChannel channel,const PixelTrait traits)
 {
+  if (((ssize_t) channel < 0) || ((ssize_t) channel >= MaxPixelChannels))
+    return;
   image->channel_map[channel].traits=traits;
 }
 
@@ -875,12 +891,12 @@ static inline void SetPixelMagentaTraits(Image *image,const PixelTrait traits)
 static inline void SetPixelMeta(const Image *magick_restrict image,
   const Quantum red,Quantum *magick_restrict pixel)
 {
-  pixel[image->channel_map[MetaPixelChannel].offset]=red;
+  pixel[image->channel_map[MetaPixelChannels].offset]=red;
 }
 
 static inline void SetPixelMetaTraits(Image *image,const PixelTrait traits)
 {
-  image->channel_map[MetaPixelChannel].traits=traits;
+  image->channel_map[MetaPixelChannels].traits=traits;
 }
 
 static inline void SetPixelReadMask(const Image *magick_restrict image,
